Remove asTextureRef from SkSpecialImage & update effects accordingly (take 2)

This CL also renames SkSpecialImage::asTextureProxy to asTextureProxyRef

This is a reland of: https://skia-review.googlesource.com/c/7995/ (Remove asTextureRef from SkSpecialImage & update effects accordingly)

It should be good to land since https://skia-review.googlesource.com/c/8701/ (Replace SkSpecialImage::makeTightSubset with asImage (take 2)) fixes the Chrome-side issue

Change-Id: I3d88b2b3d23fd69f3fb914a69dacca96cbc038a4
Reviewed-on: https://skia-review.googlesource.com/8450
Commit-Queue: Robert Phillips <robertphillips@google.com>
Reviewed-by: Brian Salomon <bsalomon@google.com>
diff --git a/tests/SpecialImageTest.cpp b/tests/SpecialImageTest.cpp
index fc59f05..80cacde 100644
--- a/tests/SpecialImageTest.cpp
+++ b/tests/SpecialImageTest.cpp
@@ -65,10 +65,10 @@
 
 #if SK_SUPPORT_GPU
     //--------------
     // Test getTextureAsRef - as long as there is a context this should succeed
     if (context) {
-        sk_sp<GrTexture> texture(img->asTextureRef(context));
-        REPORTER_ASSERT(reporter, texture);
+        sk_sp<GrTextureProxy> proxy(img->asTextureProxyRef(context));
+        REPORTER_ASSERT(reporter, proxy);
     }
 #endif
@@ -65,10 +65,10 @@
 #if SK_SUPPORT_GPU
     //--------------
-    // Test getTextureAsRef - as long as there is a context this should succeed
+    // Test asTextureProxyRef - as long as there is a context this should succeed
     if (context) {